@@ -2,14 +2,13 @@
 use FindBin qw($Bin);
 use lib $Bin;
 
-use t_Common qw/oops mytempfile mytempdir/; # strict, warnings, Carp etc.
+use t_Common qw/oops/; # strict, warnings, Carp etc.
 use t_TestCommon  # Test::More etc.
          qw/$verbose $silent $debug dprint dprintf
             bug mycheckeq_literal expect1 mycheck 
             verif_no_internals_mentioned
             insert_loc_in_evalstr verif_eval_err
             arrays_eq hash_subset
-            string_to_tempfile
             @quotes/;
 use t_SSUtils;
 
